#[non_exhaustive]pub enum PlanCacheError {
Database(SqlxError),
Serialization(Error),
Extraction(String),
}Expand description
Error type for plan cache operations.
All errors are non-fatal in the context of the planning critical path: callers should log the error and fall back to full LLM decomposition.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Database(SqlxError)
A SQLite query failed.
Serialization(Error)
JSON serialization or deserialization of a plan template failed.
Extraction(String)
Extracting a PlanTemplate from a completed TaskGraph failed.